@@ -15,7 +15,7 @@ class DynamicTreeModel;
 
 //@cond PRIVATE
 
-/**
+/*!
  * @internal
  * Test Application for proxy models.
  */
@@ -24,11 +24,11 @@ class MainWindow : public QMainWindow
     Q_OBJECT
 public:
     MainWindow();
-    ~MainWindow();
+    ~MainWindow() override;
 
 private:
     DynamicTreeModel *m_rootModel;
-//   ContactsWidget* cw;
+    //   ContactsWidget* cw;
 };
 
 //@endcond
